#
# spec file for package python-jira
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jira
Version:        3.8.0
Release:        1.1
Summary:        Python library for interacting with JIRA via REST APIs
License:        BSD-3-Clause
URL:            https://github.com/pycontribs/jira
Source:         https://files.pythonhosted.org/packages/source/j/jira/jira-%{version}.tar.gz
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module pbr >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow >= 2.1.0
Requires:       python-defusedxml
Requires:       python-keyring
Requires:       python-oauthlib
Requires:       python-packaging
Requires:       python-requests >= 2.10.0
Requires:       python-requests-oauthlib >= 0.6.1
Requires:       python-requests-toolbelt
Requires:       python-typing_extensions >= 3.7.4.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This library eases the use of the JIRA REST API from Python.

%prep
%setup -q -n jira-%{version}

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/jirashell
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Right, no test suite running, because the package tests against the
# real instance of Jira. gh#pycontribs/jira#1262

%post
%python_install_alternative jirashell

%postun
%python_uninstall_alternative jirashell

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/jirashell
%{python_sitelib}/jira
%{python_sitelib}/jira-%{version}*info

%changelog
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 3.8.0:
  * Add goal field to update/create sprint (#1806) @zbarahal
  * add backward compatibility for createmeta_issuetypes &
    createmeta_fieldtypes (#1838) @paminov
- update to 3.7.0:
  * add Release Process doc
  * Improve handling of Jira's retry-after handling
  * ISSUE-1836: Add `Dashboard` Support
  * Update createmeta warning with new method names
* Sat Mar 23 2024 Dirk Müller <dmueller@suse.com>
- add Pillow dependency
* Sat Jan 13 2024 Dirk Müller <dmueller@suse.com>
- update to 3.6.0:
  * Replace imghdr with Pillow's PIL
  * Use user_id when adding watcher
  * Fix docs building
  * gha: use pip caching from setup-python
  * #1435 - recommend installing jira[cli] to get jirashell deps
  * support pagination in createmeta methods
  * Issue Field and Issue Type object based methods
  * fix: small fix for dev docker
  * Added warning log if issue link type not present
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 3.5.2:
  * This hotfix targets the OAuth1 related regression in #1677
  * Add rich text example to docs (#1681) @ABizzinotto
  * implement SHA fallback behaviour (#1678) @adehad
  * Update `create_project()` docstring (#1676) @ABizzinotto
  * Allow the user to override the default signature method
    (#1664) @Governa
* Fri Jun  2 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.5.1:
  * Update the type for issue in add_comment & transition_issue for better
    type hints (#1580) @dvaerum
  * Switch from SIGNATURE_RSA to SIGNATURE_HMAC_SHA1 (#1643) @traylenator
  * fix verify not sent with request (#1573) (#1631) @jongracecox
- Add setuptools_scm to BuildRequires, so the version number is detected,
  and to better catch this, stop using overly greedy globbing in %%files.
- Remove Requires on python-pbr.
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 3.5.0:
  * [feature] Add support for requests timeout
  * Add projectstatuses method to get project statuses (missing
    endpoint)
  * Get the properties when fetching an Issue
  * Support for the new 'createmeta' API in Jira 8.4+
  * Make `create_issue_link` work with issue_link-objects
  * [feature] Add support for requests timeout
  * Made create_issue and create_issues consistent to handle
    multiple issue types with same name
  * KeyError: "X-RateLimit-FillRate" fix
  * Properly parse errorMessage key in error response
  * Use proper SPDX identifier
  * Remove setup.py and tidy build scripts
  * add required parameter field 'permissions' to my_permissions
    method
  * Avoid always passing on an empty body even if not given
  * Add support for IssueProperty resource
  * Add project arg to `.issue_type_by_name()`
  * fix `.add_issues_to_epic()`
  * Fix using str as issue type with `.create_issue()` when issue
    type with that name exists in many projects
  * allow filter updates when no description returned by Jira
  * Fix bug preventing use of an int for issuetype in
    `create_issue()`
  * derive attachment fname from BufferedReader object
  * [Regression] ensure `None` is handled correctly in
    `search_issues()`
  * Raise `JIRAError` when no user found
  * Add client route for deleting remote links by global (and
    internal) id
  * improve explanation of exception when two sprints with the
    same name are found
  * extend the examples with a more thorough example for getting
    attachments from a specific comment
  * Configurable batch size for `JIRA._fetch_pages()` and
    dependant methods
  * tidy ResilientSession implementation
  * Add notify to comment
  * As the keyring dependency is only used by jirashell, have it
    be part of the cli extras requirement.
  * Handle #925 rate limit error
  * updated `jira.search_issues` default behaviour to include all
    fields
  * use importlib.metadata instead of pkg_resources
  * Drop py36 py37 add py310
  * improve explanation of exception when two sprints with the
    same name are found
  * Remove GreenHopper Resource and fix Agile tests
* Sat Jun  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2.0:
  * Additional scheme endpoints for projects
  * Add subscriptable support for PropertyHolder
  * Fixing type hint to match documentation for move_to_backlog
  * improve ResultList types
  * Allow verify option as path to cert in config
  * Bugfixes
  * Locate the exact user by key if there are multiple users returned from query
  * Fixing type hint to match documentation for move_to_backlog
  * Avoid printing parsed json response
* Mon Jan 31 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add missing Requires on keyring.
* Fri Dec 10 2021 Matej Cepl <mcepl@suse.com>
- Explain, we don't have test suite running.
* Fri Dec 10 2021 pgajdos@suse.com
- version update to 3.1.1
  * lot of changes, see
    https://github.com/pycontribs/jira/releases
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Dec 20 2018 astieger@suse.com
- add missing run-time dependency on python-pbr boo#1120127
* Thu Dec  6 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 2.0.0:
  * fix pypi classifiers (#634)
  * ResultList class to support the iterator interface
  * Async improvement: Allow setting the number of worker threads for JIRA.\_fetch\_pages
  * Add Group resource
  * Changed fields type checks into single if/elif block following PR feedback
  * Create copy of fields list in JIRA.search\_issues to prevent mutating the original list
  * update pyyaml dependency
  * build: cleanup
  * Update Travis badge to travis.com
  * avoid pycrypto dependency
  * travis: fix deploy
  * build: chore
  * travis: publish workaround
  * group\_members should return sorted user keys (#611)
  * api: py37 support and rename async to async\_ (#604)
  * Fix spelling error
  * Passthrough states as a csv string
  * Remove the email\_user method as it is obsolete
  * Remove support for renaming users in Jira versions less than 6.0.0
  * travis: remove test pypi server
  * travis fixes (#608)
  * fix travis
  * Update README.rst
  * Update README to reflect branch model
  * travis fixes
  * Adopt pre-commit hooks
  * Add Bug and Feature Request Templates
  * Fix cspell problems
  * remove ordereddict requirement
  * enabled cspell check
  * Enable Attachment Test
  * Add posargs to tox.ini
  * Add Test for delete\_component
  * add a function that can delete component by id
  * added per dbaxa recommendations in PR #440
  * Add Linux compatibility to Makefile
  * decrease maximum version for external argparse
  * Missing package on setting up Sphinx
  * Fixes add\_worklog started time
  * Update docs of assign\_issue()
  * Updated docs of add\_issues\_to\_sprint()
  * Added documentation of Issue class
  * Updated doc string of search\_issue()
  * Updated doc string of sprint()
  * Remove flake8 exceptions
  * Updated doc's types for sprints()
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Apr 25 2018 tbechtold@suse.com
- update to 1.0.15:
  * Added applicationKeys parameter to add\_user (#549)
  * travis: assure prereleases are build only on master
  * Install tox-travis before using tox in the build
  * Corrected coverage execution
  * Add async support to fetch pages (#540)
  * Add support for custom session cookies to JIRA (#460)
  * Avoids AttributeError on Jira Error handling
  * travis: use service account for pypi
  * merge fixes develop branch
  * travis: pypi upload fixes
  * Implement cookie based authentication
  * gitignore: correct amps pattern fix
  * docs: replace issues shield badge
  * docs: build fixes
  * Fix README.rst images
  * Fix setup.cfg: UnicodeDecodeError
  * Add pbr >= 3.0.0 as a module dependency
  * Fix build scripts
  * jirashell: Import InteractiveShellEmbed depending on IPython version
  * Make OPTIONAL default and allowed value of mutual\_authentication
  * Add testing section to contributions
  * Update Contribution Guidlines to be more explicit
  * Place imports on separate lines
  * Touch ChangeLog To Fix PR Checks
  * Fix Continuous Integration Testing
  * Make Kerberos option mutual\_authentication configurable
  * Accept custom authentication URL
  * fixed linting errors
  * Update client.py
  * Allow through TRAVIS Environment Variables
  * Add worklog to transition\_issue()
  * Fixing move\_to\_backlog()
  * Fix bug
  * [client] Support JIRA.close()
  * add add\_user to role resource
  * added .idea/codeStyleSettings.xml to repo
  * contributing.rst: Update JIRA community link
  * contributing.rst: Remove reference to BitBucket
  * Include changelog in description
  * Move requirements extras to setup.cfg
  * #361 Made ipython a direct dependency
  * build logic and code cleanup
  * Fixed github deploy credentials
  * linting fixes
  * Forcing a rebuild
  * Pass integer ids when creating customer requests
  * Skip Service Desk tests on instances that don't support it
  * Pass ids when creating a customer request
  * Create Service Desk project during testing if it is missing
  * Add a test for create\_customer\_request
* Tue Feb 13 2018 tbechtold@suse.com
- Initial packaging (version 1.0.11)
